@@ -8,8 +8,8 @@ use strict;
 use warnings;
 use Pod::Simple::HTML;
 
-our $VERSION = '0.12'; # VERSION
-my $LAST_UPDATE = '0.12'; # manually update whenever code is changed
+our $VERSION = '1.000'; # VERSION
+my $LAST_UPDATE = '1.000'; # manually update whenever code is changed
 
 my $parser = Pod::Simple::HTML->new();
 
@@ -18,13 +18,13 @@ my ($IN, $OUT);
 if (defined $ARGV[0]) {
     open $IN, '<', $ARGV[0]  or die "Couldn't open $ARGV[0]: $!\n";
 } else {
-    *$IN = *STDIN;
+    $IN = \*STDIN;
 }
 
 if (defined $ARGV[1]) {
     open $OUT, '>', "$ARGV[1]" or die "Couldn't open $ARGV[1]: $!\n";
 } else {
-    *$OUT = *STDOUT;
+    $OUT = \*STDOUT;
 }
 
 $parser->index(1);
